==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/infocapture/classes/Event/DynamicFieldRuleChangeEvent.php <==
<?php
namespace Claromentis\Infocapture\Event;

$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"] ?: array()) + array();
use Claromentis\Core\Event\Event;
class DynamicFieldRuleChangeEvent extends Event implements ProjectEventInterface
{
    
    
    
    
    private $project;
    
    
    
    
    private $field;
    
    
    
    
    private $trigger_id;
    private $old_value;
    private $new_value;
    public function __construct(\HDProject $project, \FBField $_13d133c615714d50832f54e91fea8fb0, int $_db4c494ba9bc8ccf1ff77b060d767f58, $_fd536f3a4b49ad5514a4e7a5db1c6248, $_33e21c745c95d91261fc8f7b4b930af0)
    {
        $this->project = $project;
        $this->field = $_13d133c615714d50832f54e91fea8fb0;
        $this->trigger_id = $_db4c494ba9bc8ccf1ff77b060d767f58;
        $this->old_value = $_fd536f3a4b49ad5514a4e7a5db1c6248;
        $this->new_value = $_33e21c745c95d91261fc8f7b4b930af0;
    }
    
    
    
    
    public function getProject() : \HDProject
    {
        return $this->project;
    }
    
    
    
    
    public function getField() : \FBField
    {
        return $this->field;
    }
    
    
    
    
    public function getTriggerId() : int
    {
        return $this->trigger_id;
    }
    
    
    
    
    public function getOldValue()
    {
        return $this->old_value;
    }
    
    
    
    
    public function getNewValue()
    {
        return $this->new_value;
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/infocapture/classes/Event/DynamicFieldRuleChangeEvent.php <==
<?php
namespace Claromentis\Infocapture\Event;

$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"] = (@$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"] ?: array()) + array();
use Claromentis\Core\Event\Event;
class DynamicFieldRuleChangeEvent extends Event implements ProjectEventInterface
{
    
    
    
    
    private $project;
    
    
    
    
    private $field;
    
    
    
    
    private $trigger_id;
    private $old_value;
    private $new_value;
    public function __construct(\HDProject $project, \FBField $_13d133c615714d50832f54e91fea8fb0, int $_db4c494ba9bc8ccf1ff77b060d767f58, $_fd536f3a4b49ad5514a4e7a5db1c6248, $_33e21c745c95d91261fc8f7b4b930af0)
    {
        $this->project = $project;
        $this->field = $_13d133c615714d50832f54e91fea8fb0;
        $this->trigger_id = $_db4c494ba9bc8ccf1ff77b060d767f58;
        $this->old_value = $_fd536f3a4b49ad5514a4e7a5db1c6248;
        $this->new_value = $_33e21c745c95d91261fc8f7b4b930af0;
    }
    
    
    
    
    public function getProject() : \HDProject
    {
        return $this->project;
    }
    
    
    
    
    public function getField() : \FBField
    {
        return $this->field;
    }
    
    
    
    
    public function getTriggerId() : int
    {
        return $this->trigger_id;
    }
    
    
    
    
    public function getOldValue()
    {
        return $this->old_value;
    }
    
    
    
    
    public function getNewValue()
    {
        return $this->new_value;
    }
}
